module.exports = {
    "type":"Program",
    "loc":{
        "start":{
            "line":1,
            "column":0
        },
        "end":{
            "line":1,
            "column":12
        }
    },
    "range":[
        0,
        12
    ],
    "body":[
        {
            "type":"ExpressionStatement",
            "loc":{
                "start":{
                    "line":1,
                    "column":0
                },
                "end":{
                    "line":1,
                    "column":12
                }
            },
            "range":[
                0,
                12
            ],
            "expression":{
                "type":"JSXElement",
                "loc":{
                    "start":{
                        "line":1,
                        "column":0
                    },
                    "end":{
                        "line":1,
                        "column":11
                    }
                },
                "range":[
                    0,
                    11
                ],
                "openingElement":{
                    "type":"JSXOpeningElement",
                    "loc":{
                        "start":{
                            "line":1,
                            "column":0
                        },
                        "end":{
                            "line":1,
                            "column":5
                        }
                    },
                    "range":[
                        0,
                        5
                    ],
                    "attributes":[

                    ],
                    "name":{
                        "type":"JSXNamespacedName",
                        "loc":{
                            "start":{
                                "line":1,
                                "column":1
                            },
                            "end":{
                                "line":1,
                                "column":4
                            }
                        },
                        "range":[
                            1,
                            4
                        ],
                        "namespace":{
                            "type":"JSXIdentifier",
                            "loc":{
                                "start":{
                                    "line":1,
                                    "column":1
                                },
                                "end":{
                                    "line":1,
                                    "column":2
                                }
                            },
                            "range":[
                                1,
                                2
                            ],
                            "name":"a"
                        },
                        "name":{
                            "type":"JSXIdentifier",
                            "loc":{
                                "start":{
                                    "line":1,
                                    "column":3
                                },
                                "end":{
                                    "line":1,
                                    "column":4
                                }
                            },
                            "range":[
                                3,
                                4
                            ],
                            "name":"b"
                        }
                    },
                    "selfClosing":false
                },
                "closingElement":{
                    "type":"JSXClosingElement",
                    "loc":{
                        "start":{
                            "line":1,
                            "column":5
                        },
                        "end":{
                            "line":1,
                            "column":11
                        }
                    },
                    "range":[
                        5,
                        11
                    ],
                    "name":{
                        "type":"JSXNamespacedName",
                        "loc":{
                            "start":{
                                "line":1,
                                "column":7
                            },
                            "end":{
                                "line":1,
                                "column":10
                            }
                        },
                        "range":[
                            7,
                            10
                        ],
                        "namespace":{
                            "type":"JSXIdentifier",
                            "loc":{
                                "start":{
                                    "line":1,
                                    "column":7
                                },
                                "end":{
                                    "line":1,
                                    "column":8
                                }
                            },
                            "range":[
                                7,
                                8
                            ],
                            "name":"a"
                        },
                        "name":{
                            "type":"JSXIdentifier",
                            "loc":{
                                "start":{
                                    "line":1,
                                    "column":9
                                },
                                "end":{
                                    "line":1,
                                    "column":10
                                }
                            },
                            "range":[
                                9,
                                10
                            ],
                            "name":"b"
                        }
                    }
                },
                "children":[

                ]
            }
        }
    ],
    "sourceType":"script",
    "tokens":[
        {
            "type":"Punctuator",
            "value":"<",
            "loc":{
                "start":{
                    "line":1,
                    "column":0
                },
                "end":{
                    "line":1,
                    "column":1
                }
            },
            "range":[
                0,
                1
            ]
        },
        {
            "type":"JSXIdentifier",
            "value":"a",
            "loc":{
                "start":{
                    "line":1,
                    "column":1
                },
                "end":{
                    "line":1,
                    "column":2
                }
            },
            "range":[
                1,
                2
            ]
        },
        {
            "type":"Punctuator",
            "value":":",
            "loc":{
                "start":{
                    "line":1,
                    "column":2
                },
                "end":{
                    "line":1,
                    "column":3
                }
            },
            "range":[
                2,
                3
            ]
        },
        {
            "type":"JSXIdentifier",
            "value":"b",
            "loc":{
                "start":{
                    "line":1,
                    "column":3
                },
                "end":{
                    "line":1,
                    "column":4
                }
            },
            "range":[
                3,
                4
            ]
        },
        {
            "type":"Punctuator",
            "value":">",
            "loc":{
                "start":{
                    "line":1,
                    "column":4
                },
                "end":{
                    "line":1,
                    "column":5
                }
            },
            "range":[
                4,
                5
            ]
        },
        {
            "type":"Punctuator",
            "value":"<",
            "loc":{
                "start":{
                    "line":1,
                    "column":5
                },
                "end":{
                    "line":1,
                    "column":6
                }
            },
            "range":[
                5,
                6
            ]
        },
        {
            "type":"Punctuator",
            "value":"/",
            "loc":{
                "start":{
                    "line":1,
                    "column":6
                },
                "end":{
                    "line":1,
                    "column":7
                }
            },
            "range":[
                6,
                7
            ]
        },
        {
            "type":"JSXIdentifier",
            "value":"a",
            "loc":{
                "start":{
                    "line":1,
                    "column":7
                },
                "end":{
                    "line":1,
                    "column":8
                }
            },
            "range":[
                7,
                8
            ]
        },
        {
            "type":"Punctuator",
            "value":":",
            "loc":{
                "start":{
                    "line":1,
                    "column":8
                },
                "end":{
                    "line":1,
                    "column":9
                }
            },
            "range":[
                8,
                9
            ]
        },
        {
            "type":"JSXIdentifier",
            "value":"b",
            "loc":{
                "start":{
                    "line":1,
                    "column":9
                },
                "end":{
                    "line":1,
                    "column":10
                }
            },
            "range":[
                9,
                10
            ]
        },
        {
            "type":"Punctuator",
            "value":">",
            "loc":{
                "start":{
                    "line":1,
                    "column":10
                },
                "end":{
                    "line":1,
                    "column":11
                }
            },
            "range":[
                10,
                11
            ]
        },
        {
            "type":"Punctuator",
            "value":";",
            "loc":{
                "start":{
                    "line":1,
                    "column":11
                },
                "end":{
                    "line":1,
                    "column":12
                }
            },
            "range":[
                11,
                12
            ]
        }
    ]
};
