module.exports = {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 6,
            "column": 13
        }
    },
    "range": [
        0,
        111
    ],
    "body": [
        {
            "type": "ExpressionStatement",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 6,
                    "column": 13
                }
            },
            "range": [
                0,
                111
            ],
            "expression": {
                "type": "TemplateLiteral",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 0
                    },
                    "end": {
                        "line": 6,
                        "column": 12
                    }
                },
                "range": [
                    0,
                    110
                ],
                "expressions": [],
                "quasis": [
                    {
                        "type": "TemplateElement",
                        "loc": {
                            "start": {
                                "line": 1,
                                "column": 0
                            },
                            "end": {
                                "line": 6,
                                "column": 12
                            }
                        },
                        "range": [
                            0,
                            110
                        ],
                        "value": {
                            "raw": "The last man on Earth\n                 sat alone in a room.\n    There was\n    a knock\n    on the\n    door...",
                            "cooked": "The last man on Earth\n                 sat alone in a room.\n    There was\n    a knock\n    on the\n    door..."
                        },
                        "tail": true
                    }
                ]
            }
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "Template",
            "value": "`The last man on Earth\n                 sat alone in a room.\n    There was\n    a knock\n    on the\n    door...`",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 6,
                    "column": 12
                }
            },
            "range": [
                0,
                110
            ]
        },
        {
            "type": "Punctuator",
            "value": ";",
            "loc": {
                "start": {
                    "line": 6,
                    "column": 12
                },
                "end": {
                    "line": 6,
                    "column": 13
                }
            },
            "range": [
                110,
                111
            ]
        }
    ]
};